@@ -1,6 +1,6 @@
 /*
 
-  $Id: cfgreader.c,v 1.65 2006/02/26 16:14:59 pkot Exp $
+  $Id: cfgreader.c,v 1.74 2006/06/17 20:00:01 pkot Exp $
 
   G N O K I I
 
@@ -36,6 +36,8 @@
 
 */
 
+#define GNOKII_DEPRECATED /* do not warn about deprecated functions here */
+
 #include "config.h"
 #include "compat.h"
 #include "misc.h"
@@ -49,7 +51,7 @@
 #include "cfgreader.h"
 #include "gnokii-internal.h"
 
-API struct gn_cfg_header *gn_cfg_info;
+GNOKII_API struct gn_cfg_header *gn_cfg_info;
 static gn_config gn_config_default, gn_config_global;
 
 struct gn_cfg_header *cfg_memory_read(const char **lines)
@@ -80,8 +82,10 @@ struct gn_cfg_header *cfg_memory_read(const char **lines)
 			line[strlen(line) - 1] = '\0';
 
 		/* Ignore blank lines and comments */
-		if ((*line == '\n') || (*line == '\0') || (*line == '#'))
+		if ((*line == '\n') || (*line == '\0') || (*line == '#')) {
+			free(buf);
 			continue;
+		}
 
 		/* Look for "headings" enclosed in square brackets */
 		if ((line[0] == '[') && (line[strlen(line) - 1] == ']')) {
@@ -179,6 +183,33 @@ struct gn_cfg_header *cfg_memory_read(const char **lines)
 	return cfg_head;
 }
 
+GNOKII_API void gn_cfg_free_default()
+{
+	while (gn_cfg_info) {
+		struct gn_cfg_header *next;
+		struct gn_cfg_entry *entry;
+
+		/* free section name */
+		free(gn_cfg_info->section);
+
+		/* delete all entries */
+		entry = gn_cfg_info->entries;
+		while (entry) {
+			struct gn_cfg_entry *entry_next;
+			free(entry->key);
+			free(entry->value);
+			entry_next = entry->next;
+			free(entry);
+			entry = entry_next;
+		}
+
+		/* proceed with next section */
+		next = gn_cfg_info->next;
+		free(gn_cfg_info);
+		gn_cfg_info = next;
+	}
+}
+
 #define READ_CHUNK_SIZE 64
 
 /* Read configuration information from a ".INI" style file */
@@ -288,7 +319,7 @@ int cfg_file_write(struct gn_cfg_header *cfg, const char *filename)
  * Find the value of a key in a config file.  Return value associated
  * with key or NULL if no such key exists.
  */
-API char *gn_cfg_get(struct gn_cfg_header *cfg, const char *section, const char *key)
+GNOKII_API char *gn_cfg_get(struct gn_cfg_header *cfg, const char *section, const char *key)
 {
 	struct gn_cfg_header *h;
 	struct gn_cfg_entry *e;
@@ -316,10 +347,11 @@ API char *gn_cfg_get(struct gn_cfg_header *cfg, const char *section, const char
 /*
  * Return all the entries of the given section.
  */
-void cfg_foreach(struct gn_cfg_header *cfg, const char *section, cfg_foreach_func func)
+void cfg_foreach(const char *section, cfg_foreach_func func)
 {
 	struct gn_cfg_header *h;
 	struct gn_cfg_entry *e;
+	struct gn_cfg_header *cfg = gn_cfg_info;
 
 	if ((cfg == NULL) || (section == NULL) || (func == NULL)) {
 		return;
@@ -387,29 +419,8 @@ static bool cfg_psection_load(gn_config *cfg, const char *section, const gn_conf
 	if (!(val = gn_cfg_get(gn_cfg_info, section, "connection")))
 		cfg->connection_type = def->connection_type;
 	else {
-		if (!strcasecmp(val, "serial"))
-			cfg->connection_type = GN_CT_Serial;
-		else if (!strcasecmp(val, "dau9p"))
-			cfg->connection_type = GN_CT_DAU9P;
-		else if (!strcasecmp(val, "dlr3p"))
-			cfg->connection_type = GN_CT_DLR3P;
-		else if (!strcasecmp(val, "infrared"))
-			cfg->connection_type = GN_CT_Infrared;
-		else if (!strcasecmp(val, "m2bus"))
-			cfg->connection_type = GN_CT_M2BUS;
-		else if (!strcasecmp(val, "irda"))
-			cfg->connection_type = GN_CT_Irda;
-		else if (!strcasecmp(val, "bluetooth"))
-			cfg->connection_type = GN_CT_Bluetooth;
-		else if (!strcasecmp(val, "dku2"))
-			cfg->connection_type = GN_CT_DKU2;
-#ifndef WIN32
-		else if (!strcasecmp(val, "tcp"))
-			cfg->connection_type = GN_CT_TCP;
-#endif
-		else if (!strcasecmp(val, "tekram"))
-			cfg->connection_type = GN_CT_Tekram;
-		else {
+		cfg->connection_type = gn_get_connectiontype(val);
+		if (cfg->connection_type == GN_CT_NONE) {
 			fprintf(stderr, _("Unsupported [%s] %s value \"%s\"\n"), section, "connection", val);
 			return false;
 		}
@@ -524,12 +535,17 @@ static bool cfg_get_log_target(gn_log_target *t, const char *opt)
 }
 
 #define MAX_PATH_LEN 200
-API int gn_cfg_read_default()
+GNOKII_API int gn_cfg_read_default()
 {
 	char *homedir;
 	char rcfile[MAX_PATH_LEN];
 #ifdef WIN32
-	const char *globalrc = "gnokiirc";
+	char globalrc[MAX_PATH_LEN];
+	char *systemroot;
+
+	systemroot = getenv("SYSTEMROOT");
+	strncpy(globalrc, systemroot ? systemroot : "", MAX_PATH_LEN);
+	strncat(globalrc, "\\gnokiirc", MAX_PATH_LEN);
 
 	homedir = getenv("HOMEDRIVE");
 	strncpy(rcfile, homedir ? homedir : "", MAX_PATH_LEN);
@@ -537,7 +553,7 @@ API int gn_cfg_read_default()
 	strncat(rcfile, homedir ? homedir : "", MAX_PATH_LEN);
 	strncat(rcfile, "\\_gnokiirc", MAX_PATH_LEN);
 #else
-	const char *globalrc = "/etc/gnokiirc";
+	const char globalrc[] = "/etc/gnokiirc";
 
 	homedir = getenv("HOME");
 	if (homedir) strncpy(rcfile, homedir, MAX_PATH_LEN);
@@ -557,7 +573,7 @@ API int gn_cfg_read_default()
 }
 
 /* DEPRECATED */
-API int gn_cfg_read(char **bindir)
+GNOKII_API int gn_cfg_read(char **bindir)
 {
 	int retval;
 
@@ -638,17 +654,17 @@ static int cfg_file_or_memory_read(const char *file, const char **lines)
 	return 0;
 }
 
-API int gn_cfg_file_read(const char *file)
+GNOKII_API int gn_cfg_file_read(const char *file)
 {
 	return cfg_file_or_memory_read(file, NULL);
 }
 
-API int gn_cfg_memory_read(const char **lines)
+GNOKII_API int gn_cfg_memory_read(const char **lines)
 {
 	return cfg_file_or_memory_read(NULL, lines);
 }
 
-API int gn_cfg_phone_load(const char *iname, struct gn_statemachine *state)
+GNOKII_API int gn_cfg_phone_load(const char *iname, struct gn_statemachine *state)
 {
 	char section[256];
 
