@@ -1,6 +1,6 @@
 /*
 
-  $Id: virtmodem.c,v 1.44 2006/01/15 15:13:26 dforsi Exp $
+  $Id: virtmodem.c,v 1.46 2006/05/23 20:00:06 deller Exp $
 
   G N O K I I
 
@@ -102,7 +102,7 @@
 #endif
 
 /* Prototypes */
-static int  VM_PtySetup(char *bindir);
+static int  VM_PtySetup(const char *bindir);
 static gn_error VM_GSMInitialise(struct gn_statemachine *sm);
 
 /* Global variables */
@@ -122,7 +122,7 @@ struct vm_queue queue;
 
 /* If initialised in debug mode, stdin/out is used instead
    of ptys for interface. */
-bool gn_vm_initialise(const char *iname, char *bindir, bool debug_mode, bool GSMInit)
+bool gn_vm_initialise(const char *iname, const char *bindir, bool debug_mode, bool GSMInit)
 {
 	static struct gn_statemachine State;
 	sm = &State;
@@ -294,7 +294,8 @@ static int gread(int fd, void *ptr, size_t nbytes, int *recvfd)
 
 static int gopen(const char *command)
 {
-	int fd, sockfd[2], status;
+	int fd = -1;
+	int sockfd[2], status;
 	pid_t childpid;
 	char c, argsockfd[10];
 
@@ -342,7 +343,7 @@ static int gopen(const char *command)
 
 /* Open pseudo tty interface and (in due course create a symlink
    to be /dev/gnokii etc. ) */
-static int VM_PtySetup(char *bindir)
+static int VM_PtySetup(const char *bindir)
 {
 	char mgnokiidev[200];
 
