@@ -1,6 +1,6 @@
 /*
 
-  $Id: gsm-encoding.c,v 1.64 2005/07/31 21:42:31 pkot Exp $
+  $Id: gsm-encoding.c,v 1.69 2006/06/17 20:33:05 pkot Exp $
 
   G N O K I I
 
@@ -89,6 +89,7 @@ static unsigned char gsm_default_alphabet[GN_CHAR_ALPHABET_SIZE] = {
 
 static unsigned char gsm_reverse_default_alphabet[256];
 static bool reversed = false;
+static char application_encoding[64] = "";
 
 static void tbl_setup_reverse()
 {
@@ -107,6 +108,101 @@ static bool char_is_escape(unsigned char value)
 	return (value == GN_CHAR_ESCAPE);
 }
 
+static const char *get_langinfo_codeset(void)
+{
+	static const char *codeset = NULL;
+
+	if (!codeset) {
+#ifdef HAVE_LANGINFO_CODESET
+		codeset = nl_langinfo(CODESET);
+#else
+#  ifdef WIN32
+		/* As suggested by Ben Bryant, http://codesnipers.com/?q=node/46 */
+		char szCP[10];
+		sprintf(szCP, ".%d", GetACP());
+		codeset = setlocale(LC_ALL, szCP);
+#  else
+		codeset = locale_charset();
+#  endif
+#endif
+	}
+	return codeset;
+}
+
+GNOKII_API const char *gn_char_get_encoding()
+{
+	if (*application_encoding)
+		return application_encoding; /* app has overriden encoding setting */
+	else
+		return get_langinfo_codeset(); /* return default codeset */
+}
+
+/* detect the correct len of a string (also for multibyte chars like "umlaute") */
+int char_mblen(const char *src)
+{
+	int len = mbstowcs(NULL, src, 0);
+	dprintf("char_mblen(%s): %i\n", src, len);
+	return len;
+}
+
+static int char_mbtowc(wchar_t *dst, const char *src, int maxlen, MBSTATE *mbs)
+{
+#ifdef HAVE_ICONV
+	size_t nconv;
+	char *pin;
+	char *pout;
+	int inlen;
+	int outlen;
+	iconv_t cd;
+
+	pin = (char *)src;
+	pout = (char *)dst;
+	inlen = 4;
+	outlen = 4;
+
+	cd = iconv_open("WCHAR_T", gn_char_get_encoding());
+	nconv = iconv(cd, &pin, &inlen, &pout, &outlen);
+	iconv_close(cd);
+	
+	return (char*)dst == pout ? -1 : pin-src;
+#else
+#  ifdef HAVE_WCRTOMB
+        return mbrtowc(dst, src, maxlen, mbs);
+#  else
+        return mbtowc(dst, src, maxlen);
+#  endif
+#endif
+}
+
+static int char_wctomb(char *dst, wchar_t src, MBSTATE *mbs)
+{
+#ifdef HAVE_ICONV
+	size_t nconv;
+	char *pin;
+	char *pout;
+	int inlen;
+	int outlen;
+	iconv_t cd;
+
+	pin = (char *)&src;
+	pout = (char *)dst;
+	inlen = 4;
+	outlen = 4;
+	
+	cd = iconv_open(gn_char_get_encoding(), "WCHAR_T");
+	nconv = iconv(cd, &pin, &inlen, &pout, &outlen);
+	iconv_close(cd);
+	
+	return nconv == -1 ? -1 : pout-dst;
+#else
+    #ifdef HAVE_WCRTOMB
+	return wcrtomb(dst, src, mbs);
+    #else
+	return wctomb(dst, src);
+    #endif
+#endif
+}
+
 /*
  * In GSM specification there are 10 characters in the extension
  * of the default alphabet. Their values look a bit random, they are
@@ -118,7 +214,7 @@ static bool char_def_alphabet_ext(unsigned char value)
 {
 	wchar_t retval;
 
-	if (mbtowc(&retval, &value, 1) == -1) return false;
+	if (char_mbtowc(&retval, &value, 1, NULL) == -1) return false;
 	return (value == 0x0c ||
 		value == '^' ||
 		value == '{' ||
@@ -165,7 +261,7 @@ static unsigned char char_def_alphabet_ext_encode(unsigned char value)
 	}
 }
 
-API bool gn_char_def_alphabet(unsigned char *string)
+GNOKII_API bool gn_char_def_alphabet(unsigned char *string)
 {
 	unsigned int i, len = strlen(string);
 
@@ -345,11 +441,7 @@ int char_uni_alphabet_encode(unsigned char const *value, wchar_t *dest, MBSTATE
 {
 	int length;
 
-#ifdef HAVE_WCRTOMB
-	switch (length = mbrtowc(dest, value, MB_CUR_MAX, mbs)) {
-#else
-	switch (length = mbtowc(dest, value, MB_CUR_MAX)) {
-#endif
+	switch (length = char_mbtowc(dest, value, MB_CUR_MAX, mbs)) {
 	case -1:
 		dprintf("Error calling mctowb!\n");
 		*dest = '?';
@@ -363,11 +455,7 @@ int char_uni_alphabet_decode(wchar_t value, unsigned char *dest, MBSTATE *mbs)
 {
 	int length;
 
-#ifdef HAVE_WCRTOMB
-	switch (length = wcrtomb(dest, value, mbs)) {
-#else
-	switch (length = wctomb(dest, value)) {
-#endif
+    switch (length = char_wctomb(dest, value, mbs)) {
 	case -1:
 		*dest = '?';
 		length = 1;
@@ -561,7 +649,7 @@ char *char_bcd_number_get(u8 *number)
 {
 	static char buffer[GN_BCD_STRING_MAX_LENGTH] = "";
 	int length = number[0]; /* This is the length of BCD coded number */
-	int count, digit;
+	int count, digit, i = 0;
 
 	if (length > GN_BCD_STRING_MAX_LENGTH) length = GN_BCD_STRING_MAX_LENGTH;
 	memset(buffer, 0, GN_BCD_STRING_MAX_LENGTH);
@@ -572,6 +660,7 @@ char *char_bcd_number_get(u8 *number)
 		break;
 	case GN_GSM_NUMBER_International:
 		sprintf(buffer, "+");
+		i++;
 		if (length == GN_BCD_STRING_MAX_LENGTH) length--; /* avoid overflow */
 	case GN_GSM_NUMBER_Unknown:
 	case GN_GSM_NUMBER_National:
@@ -581,27 +670,21 @@ char *char_bcd_number_get(u8 *number)
 	default:
 		for (count = 0; count < length - 1; count++) {
 			digit = number[count+2] & 0x0f;
-			if (digit < 10) sprintf(buffer, "%s%d", buffer, digit);
+			if (digit < 10)
+				buffer[i++] = digit + '0';
 			digit = number[count+2] >> 4;
-			if (digit < 10) sprintf(buffer, "%s%d", buffer, digit);
+			if (digit < 10)
+				buffer[i++] = digit + '0';
 		}
 		break;
 	}
 	return buffer;
 }
 
-static const char *get_langinfo_codeset(void)
+void gn_char_set_encoding(const char* encoding)
 {
-	static const char *codeset = NULL;
-
-	if (!codeset) {
-#ifdef HAVE_LANGINFO_CODESET
-		codeset = nl_langinfo(CODESET);
-#else
-		codeset = locale_charset();
-#endif
-	}
-	return codeset;
+	strncpy(application_encoding, encoding, sizeof(application_encoding) - 1);
+	application_encoding[sizeof(application_encoding) - 1] = 0;
 }
 
 /* UTF-8 conversion functions */
@@ -616,8 +699,8 @@ int utf8_decode(char *outstring, size_t outlen, const char *instring, size_t inl
 
 	pin = (char *)instring;
 	pout = outstring;
-
-	cd = iconv_open(get_langinfo_codeset(), "UTF-8");
+	
+	cd = iconv_open(gn_char_get_encoding(), "UTF-8");
 	nconv = iconv(cd, &pin, &inlen, &pout, &outlen);
 	iconv_close(cd);
 	*pout = 0;
@@ -673,7 +756,7 @@ int utf8_encode(char *outstring, int outlen, const char *instring, int inlen)
 	pin = (char *)instring;
 	pout = outstring;
 
-	cd = iconv_open("UTF-8", get_langinfo_codeset());
+	cd = iconv_open("UTF-8", gn_char_get_encoding());
 
 	nconv = iconv(cd, &pin, &inleft, &pout, &outleft);
 	*pout = 0;
