@@ -1,6 +1,6 @@
 /*
 
-  $Id: gsm-sms.c,v 1.147 2005/06/30 21:27:43 pkot Exp $
+  $Id: gsm-sms.c,v 1.149 2006/06/11 16:39:48 deller Exp $
 
   G N O K I I
 
@@ -111,14 +111,14 @@ static void sms_default(gn_sms *sms)
 	sms->dcs.u.general.m_class = 0;
 }
 
-API void gn_sms_default_submit(gn_sms *sms)
+GNOKII_API void gn_sms_default_submit(gn_sms *sms)
 {
 	sms_default(sms);
 	sms->type = GN_SMS_MT_Submit;
 	sms->memory_type = GN_MT_SM;
 }
 
-API void gn_sms_default_deliver(gn_sms *sms)
+GNOKII_API void gn_sms_default_deliver(gn_sms *sms)
 {
 	sms_default(sms);
 	sms->type = GN_SMS_MT_Deliver;
@@ -141,7 +141,9 @@ static char *sms_timestamp_print(u8 *number)
 {
 #ifdef DEBUG
 #define LOCAL_DATETIME_MAX_LENGTH 23
-	static unsigned char buffer[LOCAL_DATETIME_MAX_LENGTH] = "";
+	static char buffer[LOCAL_DATETIME_MAX_LENGTH];
+	char buf[5];
+	int i;
 
 	if (!number) return NULL;
 
@@ -154,22 +156,22 @@ static char *sms_timestamp_print(u8 *number)
 	else
 		sprintf(buffer, "19");
 
-	sprintf(buffer, "%s%d%d-", buffer, number[0] & 0x0f, number[0] >> 4);
-	sprintf(buffer, "%s%d%d-", buffer, number[1] & 0x0f, number[1] >> 4);
-	sprintf(buffer, "%s%d%d ", buffer, number[2] & 0x0f, number[2] >> 4);
-	sprintf(buffer, "%s%d%d:", buffer, number[3] & 0x0f, number[3] >> 4);
-	sprintf(buffer, "%s%d%d:", buffer, number[4] & 0x0f, number[4] >> 4);
-	sprintf(buffer, "%s%d%d",  buffer, number[5] & 0x0f, number[5] >> 4);
+	for (i = 0; i < 6; i++) {
+		char buf2[4];
+		snprintf(buf2, 4, "%d%d-", number[i] & 0x0f, number[i] >> 4);
+		strcat(buffer, buf2);
+	}
 
 	/* The GSM spec is not clear what is the sign of the timezone when the
 	 * 6th bit is set. Some SMSCs are compatible with our interpretation,
 	 * some are not. If your operator does use incompatible SMSC and wrong
 	 * sign disturbs you, change the sign here.
 	 */
-	if (number[6] & 0x08) sprintf(buffer, "%s-", buffer);
-	else sprintf(buffer, "%s+", buffer);
+	if (number[6] & 0x08) strcat(buffer, "-");
+	else strcat(buffer, "+");
 	/* The timezone is given in quarters. The base is GMT. */
-	sprintf(buffer, "%s%02d00", buffer, (10 * (number[6] & 0x07) + (number[6] >> 4)) / 4);
+	sprintf(buf, "%02d00", (10 * (number[6] & 0x07) + (number[6] >> 4)) / 4);
+	strcat(buffer, buf);
 
 	return buffer;
 #undef LOCAL_DATETIME_MAX_LENGTH
@@ -696,7 +698,7 @@ static gn_error sms_pdu_decode(gn_sms_raw *rawsms, gn_sms *sms)
  * the highlevel SMS. In data->raw_sms there's SMS read by the phone
  * driver, data->sms is the place for the parsed SMS.
  */
-API gn_error gn_sms_parse(gn_data *data)
+GNOKII_API gn_error gn_sms_parse(gn_data *data)
 {
 	if (!data->raw_sms || !data->sms) return GN_ERR_INTERNALERROR;
 	/* Let's assume at the moment that all messages are PDU coded */
@@ -712,7 +714,7 @@ API gn_error gn_sms_parse(gn_data *data)
  * phone driver. Not that raw_sms field in the gn_data structure must
  * be initialized
  */
-API gn_error gn_sms_request(gn_data *data, struct gn_statemachine *state)
+GNOKII_API gn_error gn_sms_request(gn_data *data, struct gn_statemachine *state)
 {
 	if (!data->raw_sms) return GN_ERR_INTERNALERROR;
 	return gn_sm_functions(GN_OP_GetSMS, data, state);
@@ -726,7 +728,7 @@ API gn_error gn_sms_request(gn_data *data, struct gn_statemachine *state)
  * This function is the frotnend for reading SMS. Note that SMS field
  * in the gn_data structure must be initialized.
  */
-API gn_error gn_sms_get(gn_data *data, struct gn_statemachine *state)
+GNOKII_API gn_error gn_sms_get(gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error;
 	gn_sms_raw rawsms;
@@ -750,7 +752,7 @@ API gn_error gn_sms_get(gn_data *data, struct gn_statemachine *state)
  * This function is the frontend for deleting SMS. Note that SMS field
  * in the gn_data structure must be initialized.
  */
-API gn_error gn_sms_delete(gn_data *data, struct gn_statemachine *state)
+GNOKII_API gn_error gn_sms_delete(gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms_raw rawsms;
 
@@ -771,7 +773,7 @@ static gn_error sms_request_no_validate(gn_data *data, struct gn_statemachine *s
 	return gn_sm_functions(GN_OP_GetSMSnoValidate, data, state);
 }
 
-API gn_error gn_sms_get_no_validate(gn_data *data, struct gn_statemachine *state)
+GNOKII_API gn_error gn_sms_get_no_validate(gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error;
 	gn_sms_raw rawsms;
@@ -787,7 +789,7 @@ API gn_error gn_sms_get_no_validate(gn_data *data, struct gn_statemachine *state
 	return gn_sms_parse(data);
 }
 
-API gn_error gn_sms_delete_no_validate(gn_data *data, struct gn_statemachine *state)
+GNOKII_API gn_error gn_sms_delete_no_validate(gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms_raw rawsms;
 
@@ -895,7 +897,7 @@ static gn_error sms_verify_status(gn_data *data)
 }
 
 
-API gn_error gn_sms_get_folder_changes(gn_data *data, struct gn_statemachine *state, int has_folders)
+GNOKII_API gn_error gn_sms_get_folder_changes(gn_data *data, struct gn_statemachine *state, int has_folders)
 {
 	gn_error error;
 	gn_sms_folder  sms_folder;
@@ -1275,7 +1277,7 @@ static gn_error sms_send_long(gn_data *data, struct gn_statemachine *state);
  * and then phone driver takes the fields it needs and sends it in the
  * phone specific way to the phone.
  */
-API gn_error gn_sms_send(gn_data *data, struct gn_statemachine *state)
+GNOKII_API gn_error gn_sms_send(gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error = GN_ERR_NONE;
 
@@ -1309,7 +1311,7 @@ API gn_error gn_sms_send(gn_data *data, struct gn_statemachine *state)
 	return error;
 }
 
-API int gn_sms_udh_add(gn_sms *sms, gn_sms_udh_type type)
+GNOKII_API int gn_sms_udh_add(gn_sms *sms, gn_sms_udh_type type)
 {
 	sms->udh.length += headers[type].length;
 	sms->udh.udh[sms->udh.number].type = type;
@@ -1409,7 +1411,7 @@ static gn_error sms_send_long(gn_data *data, struct gn_statemachine *state)
 	return GN_ERR_NONE;
 }
 
-API gn_error gn_sms_save(gn_data *data, struct gn_statemachine *state)
+GNOKII_API gn_error gn_sms_save(gn_data *data, struct gn_statemachine *state)
 {
 	gn_error error = GN_ERR_NONE;
 	gn_sms_raw rawsms;
