@@ -1,6 +1,6 @@
 /*
 
-  $Id: misc.c,v 1.105 2005/11/24 00:27:16 bozo Exp $
+  $Id: misc.c,v 1.111 2006/06/11 16:39:48 deller Exp $
 
   G N O K I I
 
@@ -55,12 +55,12 @@
 #include "misc.h"
 #include "gnokii.h"
 
-API gn_log_target gn_log_debug_mask = GN_LOG_T_NONE;
-API gn_log_target gn_log_rlpdebug_mask = GN_LOG_T_NONE;
-API gn_log_target gn_log_xdebug_mask = GN_LOG_T_NONE;
-API void (*gn_elog_handler)(const char *fmt, va_list ap) = NULL;
+GNOKII_API gn_log_target gn_log_debug_mask = GN_LOG_T_NONE;
+GNOKII_API gn_log_target gn_log_rlpdebug_mask = GN_LOG_T_NONE;
+GNOKII_API gn_log_target gn_log_xdebug_mask = GN_LOG_T_NONE;
+GNOKII_API void (*gn_elog_handler)(const char *fmt, va_list ap) = NULL;
 
-API int gn_line_get(FILE *file, char *line, int count)
+GNOKII_API int gn_line_get(FILE *file, char *line, int count)
 {
 	char *ptr;
 
@@ -77,7 +77,7 @@ API int gn_line_get(FILE *file, char *line, int count)
 }
 
 static gn_phone_model models[] = {
-	{NULL,    "", 0 },
+	/* model, product_name, ... */
 	{"2711",  "?????", PM_SMS },		/* Dancall */
 	{"2731",  "?????", PM_SMS },
 	{"11",    "TFF-3", 0 },
@@ -139,16 +139,16 @@ static gn_phone_model models[] = {
 	{"3120b", "RH-50", PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"3200",  "RH-30", 0 },
 	{"3200b", "RH-31", 0 },
-	{"3210",  "NSE-8", PM_SMS | PM_DTMF | PM_KEYBOARD },
+	{"3210",  "NSE-8", PM_SPEEDDIAL | PM_SMS | PM_DTMF | PM_KEYBOARD },
 	{"3210",  "NSE-9", PM_SMS | PM_DTMF | PM_KEYBOARD },
 	{"3285",  "NSD-1A", 0 },
 	{"3300",  "NEM-1", 0 },
 	{"3300",  "NEM-2", 0 },
-	{"3310",  "NHM-5", PM_SMS | PM_DTMF },
+	{"3310",  "NHM-5", PM_SPEEDDIAL | PM_SMS | PM_DTMF },
 	{"3310",  "NHM-5NX", PM_SMS | PM_DTMF },
 	{"3315",  "NHM-5NY", PM_SMS | PM_DTMF },
 	{"3320",  "NPC-1", 0 },
-	{"3330",  "NHM-6", PM_SMS | PM_DTMF },
+	{"3330",  "NHM-6", PM_SPEEDDIAL | PM_SMS | PM_DTMF },
 	{"3350",  "NHM-9", PM_SMS | PM_DTMF },
 	{"3360",  "NPW-6", PM_SMS | PM_DTMF },
 	{"3360",  "NPW-1", PM_SMS | PM_DTMF },
@@ -215,6 +215,7 @@ static gn_phone_model models[] = {
 	{"6160",  "NSW-3AX", 0 },
 	{"6161",  "NSW-3ND", 0 },
 	{"6162",  "NSW-3AF", 0 },
+	{"6170",  "RM47_-48", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_EXTPBK | PM_SMS | PM_FOLDERS },
 	{"6185",  "NSD-3", PM_CALLERGROUP | PM_CALENDAR | PM_NETMONITOR | PM_KEYBOARD | PM_SMS | PM_DTMF | PM_DATA | PM_SPEEDDIAL | PM_AUTHENTICATION },
 	{"6185i", "NSD-3AW", 0 },
 	{"6188",  "NSD-3AX", 0 },
@@ -301,29 +302,38 @@ static gn_phone_model models[] = {
 	{"N-Gage", "NEM-4", 0},
 	{"RinGo", "NHX-7", 0},
 	{"sx1",  "SX1", PM_CALLERGROUP | PM_CALENDAR | PM_SPEEDDIAL | PM_NETMONITOR | PM_EXTPBK | PM_SMS | PM_FOLDERS },
-	{NULL,    NULL, 0 }
+	{NULL,    NULL, 0 } /* keep last one as NULL */
 };
 
-API gn_phone_model *gn_phone_model_get(const char *num)
-{
-	register int i = 0;
+#define MODELS_NUM_ENTRIES (sizeof(models)/sizeof(models[0]))
 
-	while (models[i].number != NULL) {
-		if (strcmp(num, models[i].number) == 0) {
-			dprintf("Found model \"%s\"\n", num);
+/* this should be in libfunctions - will move it there with next version of libgnokii */
+GNOKII_API const char *gn_lib_get_supported_phone_model( const int num )
+{
+	if (num < 0 || num >= MODELS_NUM_ENTRIES)
+		return NULL;
+	return models[num].model;
+}
+
+
+GNOKII_API gn_phone_model *gn_phone_model_get(const char *product_name)
+{
+	int i = 0;
+
+	while (models[i].product_name != NULL) {
+		if (strcmp(product_name, models[i].product_name) == 0) {
+			dprintf("Found model \"%s\"\n", product_name);
 			return (&models[i]);
-		} else {
-			dprintf("comparing \"%s\" and \"%s\"\n", num, models[i].number);
 		}
 		i++;
 	}
 
-	return (&models[0]);
+	return (&models[MODELS_NUM_ENTRIES-1]); /* NULL entry */
 }
 
-API char *gn_model_get(const char *num)
+GNOKII_API const char *gn_model_get(const char *product_name)
 {
-	return (gn_phone_model_get(num)->model);
+	return (gn_phone_model_get(product_name)->model);
 }
 
 static void log_printf(gn_log_target mask, const char *fmt, va_list ap)
@@ -334,7 +344,7 @@ static void log_printf(gn_log_target mask, const char *fmt, va_list ap)
 	}
 }
 
-API void gn_log_debug(const char *fmt, ...)
+GNOKII_API void gn_log_debug(const char *fmt, ...)
 {
 #ifdef DEBUG
 	va_list ap;
@@ -347,7 +357,7 @@ API void gn_log_debug(const char *fmt, ...)
 #endif
 }
 
-API void gn_log_rlpdebug(const char *fmt, ...)
+GNOKII_API void gn_log_rlpdebug(const char *fmt, ...)
 {
 #ifdef RLP_DEBUG
 	va_list ap;
@@ -360,7 +370,7 @@ API void gn_log_rlpdebug(const char *fmt, ...)
 #endif
 }
 
-API void gn_log_xdebug(const char *fmt, ...)
+GNOKII_API void gn_log_xdebug(const char *fmt, ...)
 {
 #ifdef XDEBUG
 	va_list ap;
@@ -373,7 +383,7 @@ API void gn_log_xdebug(const char *fmt, ...)
 #endif
 }
 
-API void gn_elog_write(const char *fmt, ...)
+GNOKII_API void gn_elog_write(const char *fmt, ...)
 {
 	va_list ap;
 
@@ -401,7 +411,7 @@ API void gn_elog_write(const char *fmt, ...)
 #endif
 
 /* Lock the device. Return allocated string with a lock name */
-API char *gn_device_lock(const char* port)
+GNOKII_API char *gn_device_lock(const char* port)
 {
 #ifndef WIN32
 	char *lock_file = NULL;
@@ -502,7 +512,7 @@ failed:
 }
 
 /* Removes lock and frees memory */
-API bool gn_device_unlock(char *lock_file)
+GNOKII_API bool gn_device_unlock(char *lock_file)
 {
 #ifndef WIN32
 	int err;
@@ -572,7 +582,7 @@ void gnokii_strfreev(char **str_array)
 /*
  * check if the timestamp in dt has valid date and time
  */
-API int gn_timestamp_isvalid(gn_timestamp dt)
+GNOKII_API int gn_timestamp_isvalid(gn_timestamp dt)
 {
 #define BETWEEN(a, x, y)	((a >= x) && (a <= y))
 	int daynum;
