@@ -1,6 +1,6 @@
 /*
 
-  $Id: nokia-decoding.c,v 1.27 2006/01/22 13:38:06 pkot Exp $
+  $Id: nokia-decoding.c,v 1.29 2006/05/22 20:03:52 pkot Exp $
 
   G N O K I I
 
@@ -37,10 +37,11 @@
 */
 
 #include <time.h>
-
+#include "config.h"
 #include "gnokii-internal.h" 
 #include "gnokii.h"
 #include "nokia-decoding.h"
+#include "compat.h"
 
 gn_error phonebook_decode(unsigned char *blockstart, int length, gn_data *data,
 			  int blocks, int memtype, int speeddial_pos)
@@ -145,6 +146,7 @@ gn_error phonebook_decode(unsigned char *blockstart, int length, gn_data *data,
 			dprintf("   Number: %s\n", subentry->data.number);
 			subblock_count++;
 			data->phonebook_entry->subentries_count++;
+			data->phonebook_entry->empty = false;
 			break;
 		case GN_PHONEBOOK_ENTRY_Ringtone:  /* Ringtone */
 			if (data->bitmap) {
