@@ -1,6 +1,6 @@
 /*
 
-  $Id: atgen.c,v 1.118 2006/02/13 20:39:11 bozo Exp $
+  $Id: atgen.c,v 1.125 2006/05/08 17:54:49 deller Exp $
 
   G N O K I I
 
@@ -173,7 +173,7 @@ static char *strip_brackets(char *s)
 	return s;
 }
 
-static void reply_simpletext(char *l1, char *l2, char *c, char *t)
+static void reply_simpletext(char *l1, char *l2, char *c, char *t, size_t maxlength)
 {
 	int i, n;
 
@@ -181,11 +181,12 @@ static void reply_simpletext(char *l1, char *l2, char *c, char *t)
 	if ((strncmp(l1, c, n - 2) == 0) && (t != NULL)) {
 		if (strncmp(l2, c, n) == 0)  {
 			for (i = n; isspace(l2[i]); i++) ;
-			strcpy(t, strip_quotes(l2 + i));
+			strncpy(t, strip_quotes(l2 + i), maxlength);
 		} else {
 			for (i = 0; isspace(l2[i]); i++) ;
-			strcpy(t, l2 + i);
+			strncpy(t, l2 + i, maxlength);
 		}
+		t[maxlength - 1] = '\0';
 	}
 }
 
@@ -551,6 +552,8 @@ gn_error AT_SetSMSMemoryType(gn_memory_type mt, struct gn_statemachine *state)
 	gn_error ret = GN_ERR_NONE;
 
 	if (mt != drvinst->smsmemorytype) {
+		if (mt >= NR_MEMORIES)
+			return GN_ERR_INVALIDMEMORYTYPE;
 		gn_data_clear(&data);
 		data.sms_status = &sms_status;
 		ret = AT_GetSMSStatus(&data, state);
@@ -847,7 +850,7 @@ static gn_error AT_DeletePhonebook(gn_data *data, struct gn_statemachine *state)
 
 static gn_error AT_CallDivert(gn_data *data, struct gn_statemachine *state)
 {
-	char req[64];
+	char req[64], req2[64];
 
 	if (!data->call_divert) return GN_ERR_UNKNOWN;
 
@@ -870,14 +873,17 @@ static gn_error AT_CallDivert(gn_data *data, struct gn_statemachine *state)
 		dprintf("3. %d\n", data->call_divert->type);
 		return GN_ERR_NOTIMPLEMENTED;
 	}
-	if (data->call_divert->operation == GN_CDV_Register)
-		sprintf(req, "%s,%d,\"%s\",%d,,,%d", req,
+	if (data->call_divert->operation == GN_CDV_Register) {
+		sprintf(req2, ",%d,\"%s\",%d,,,%d",
 			data->call_divert->operation,
 			data->call_divert->number.number,
 			data->call_divert->number.type,
 			data->call_divert->timeout);
-	else
-		sprintf(req, "%s,%d", req, data->call_divert->operation);
+		strcat(req, req2);
+	} else {
+		sprintf(req2, ",%d", data->call_divert->operation);
+		strcat(req, req2);
+	}
 
 	strcat(req, "\r");
 
@@ -1178,6 +1184,7 @@ static gn_error ReplyReadPhonebook(int messagetype, unsigned char *buffer, int l
 
 		/* store number */
 		pos = strchr(buf.line2, '\"');
+		dprintf("NUMBER: %s\n", pos);
 		endpos = NULL;
 		if (pos)
 			endpos = strchr(++pos, '\"');
@@ -1190,6 +1197,7 @@ static gn_error ReplyReadPhonebook(int messagetype, unsigned char *buffer, int l
 		pos = NULL;
 		if (endpos)
 			pos = strchr(endpos+2, ',');
+		dprintf("NAME: %s\n", pos);
 		endpos = NULL;
 		if (pos) {
 			pos = strip_quotes(pos+1);
@@ -1382,15 +1390,18 @@ static gn_error ReplyIdentify(int messagetype, unsigned char *buffer, int length
 	buf.length = length;
 	splitlines(&buf);
 	if (!strncmp(buf.line1, "AT+CG", 5)) {
-		reply_simpletext(buf.line1+2, buf.line2, "+CGSN: ", data->imei);
-		reply_simpletext(buf.line1+2, buf.line2, "+CGMM: ", data->model);
-		reply_simpletext(buf.line1+2, buf.line2, "+CGMI: ", data->manufacturer);
-		reply_simpletext(buf.line1+2, buf.line2, "+CGMR: ", data->revision);
+		reply_simpletext(buf.line1+2, buf.line2, "+CGSN: ", data->imei, GN_IMEI_MAX_LENGTH);
+		if (!data->model[0])
+			reply_simpletext(buf.line1+2, buf.line2, "+CGMM: ", data->model, GN_MODEL_MAX_LENGTH);
+		reply_simpletext(buf.line1+2, buf.line2, "+CGMI: ", data->manufacturer, GN_MANUFACTURER_MAX_LENGTH);
+		reply_simpletext(buf.line1+2, buf.line2, "+CGMR: ", data->revision, GN_REVISION_MAX_LENGTH);
+		reply_simpletext(buf.line1+2, buf.line4, "+CGMR: ", data->model, GN_MODEL_MAX_LENGTH);
 	} else if (!strncmp(buf.line1, "AT+G", 4)) {
-		reply_simpletext(buf.line1+2, buf.line2, "+GSN: ", data->imei);
-		reply_simpletext(buf.line1+2, buf.line2, "+GMM: ", data->model);
-		reply_simpletext(buf.line1+2, buf.line2, "+GMI: ", data->manufacturer);
-		reply_simpletext(buf.line1+2, buf.line2, "+GMR: ", data->revision);
+		reply_simpletext(buf.line1+2, buf.line2, "+GSN: ", data->imei, GN_IMEI_MAX_LENGTH);
+		if (!data->model[0])
+			reply_simpletext(buf.line1+2, buf.line2, "+GMM: ", data->model, GN_MODEL_MAX_LENGTH);
+		reply_simpletext(buf.line1+2, buf.line2, "+GMI: ", data->manufacturer, GN_MANUFACTURER_MAX_LENGTH);
+		reply_simpletext(buf.line1+2, buf.line2, "+GMR: ", data->revision, GN_REVISION_MAX_LENGTH);
 	}
 	return GN_ERR_NONE;
 }
@@ -1744,9 +1755,7 @@ static gn_error ReplyGetNetworkInfo(int messagetype, unsigned char *buffer, int
 		format = atoi(strings[1]);
 		switch (format) {
 		case 0: /* network operator name given */
-			pos = strings[2];
-			pos++;
-			pos = strtok(pos, "\"");
+			pos = strip_quotes(strings[2]);
 			at_decode(drvinst->charset, tmp, pos, strlen(pos));
 			snprintf(data->network_info->network_code, sizeof(data->network_info->network_code), gn_network_code_get(tmp));
 			break;
@@ -1793,8 +1802,8 @@ static gn_error Initialise(gn_data *setupdata, struct gn_statemachine *state)
 	at_driver_instance *drvinst;
 	gn_data data;
 	gn_error ret = GN_ERR_NONE;
-	char model[64];
-	char manufacturer[64];
+	char model[GN_MODEL_MAX_LENGTH];
+	char manufacturer[GN_MANUFACTURER_MAX_LENGTH];
 	int i;
 
 	dprintf("Initializing AT capable mobile phone ...\n");
@@ -1921,6 +1930,10 @@ void splitlines(at_line_buffer *buf)
 	} else {
 		buf->line4 = buf->line3;
 	}
+	pos = findcrlf(buf->line4, 1, buf->length);
+	if (pos) {
+		*pos = 0;
+	}
 }
 
 /*
