@@ -1,6 +1,6 @@
 /*
 
-  $Id: vcard.c,v 1.16 2005/05/10 09:58:59 pkot Exp $
+  $Id: vcard.c,v 1.18 2006/06/11 16:39:48 deller Exp $
   
   G N O K I I
 
@@ -36,7 +36,7 @@
 #include "gnokii.h"
 #include "gnokii-internal.h"
 
-API int gn_phonebook2vcard(FILE * f, gn_phonebook_entry *entry, char *location)
+GNOKII_API int gn_phonebook2vcard(FILE * f, gn_phonebook_entry *entry, char *location)
 {
 	int i;
 	char name[2 * GN_PHONEBOOK_NAME_MAX_LENGTH];
@@ -48,6 +48,27 @@ API int gn_phonebook2vcard(FILE * f, gn_phonebook_entry *entry, char *location)
 	fprintf(f, "TEL;VOICE:%s\n", entry->number);
 	fprintf(f, "X_GSM_STORE_AT:%s\n", location);
 	fprintf(f, "X_GSM_CALLERGROUP:%d\n", entry->caller_group);
+	fprintf(f, "CATEGORIES:");
+	switch (entry->caller_group) {
+	case GN_PHONEBOOK_GROUP_Family:
+		fprintf(f, "Family\n");
+		break;
+	case GN_PHONEBOOK_GROUP_Vips:
+		fprintf(f, "VIPs\n");	
+		break;
+	case GN_PHONEBOOK_GROUP_Friends:	
+		fprintf(f, "Friends\n");
+		break;
+	case GN_PHONEBOOK_GROUP_Work:
+		fprintf(f, "Work\n");
+		break;
+	case GN_PHONEBOOK_GROUP_Others:
+		fprintf(f, "Others\n");
+		break;
+	default:
+		fprintf(f, "Unkown\n");
+		break;	
+	}
 
 	/* Add ext. pbk info if required */
 	for (i = 0; i < entry->subentries_count; i++) {
@@ -117,7 +138,7 @@ API int gn_phonebook2vcard(FILE * f, gn_phonebook_entry *entry, char *location)
 #define ERROR(a) fprintf(stderr, "%s\n", a)
 
 /* We assume gn_phonebook_entry is ready for writing in, ie. no rubbish inside */
-API int gn_vcard2phonebook(FILE *f, gn_phonebook_entry *entry)
+GNOKII_API int gn_vcard2phonebook(FILE *f, gn_phonebook_entry *entry)
 {
 	char buf[1024];
 	char memloc[10];
