@@ -1,6 +1,6 @@
 /*
 
-  $Id: compat.h,v 1.41 2005/04/24 19:13:13 pkot Exp $
+  $Id: compat.h,v 1.45 2006/06/11 16:39:11 deller Exp $
 
   G N O K I I
 
@@ -40,6 +40,7 @@
 
 #ifdef WIN32
 #  include <windows.h>
+#  include <locale.h>
 #  ifdef HAVE_DIRECT_H
 #    include <direct.h>
 #  endif
@@ -105,14 +106,16 @@
  */
 #if defined(WIN32)
 #  if defined(GNOKIIDLL_EXPORTS) || defined(_USRDLL) || defined(DLL_EXPORT)
-#    define API __declspec(dllexport)
+#    define GNOKII_API __declspec(dllexport)
 #  elif defined(GNOKIIDLL_IMPORTS)
-#    define API __declspec(dllimport)
+#    define GNOKII_API __declspec(dllimport)
 #  else
-#    define API
+#    define GNOKII_API
 #  endif
-#else /* !WIN32 */
-#  define API
+#elif (__GNUC__ - 0 > 3)
+#    define GNOKII_API __attribute__ ((visibility("default")))
+#else
+#    define GNOKII_API
 #endif /* WIN32 */
 
 #ifndef	HAVE_TIMEOPS
@@ -179,6 +182,10 @@ int asprintf(char **ptr, const char *format, ...);
 int vasprintf(char **ptr, const char *format, va_list ap);
 #endif
 
+#ifndef HAVE_TIMEGM
+time_t timegm(struct tm *tm);
+#endif
+
 /*
  * The following code was taken from W. Richard Stevens'
  * "UNIX Network Programming", Volume 1, Second Edition.
