@@ -1,6 +1,6 @@
 /*
 
-  $Id: common.h,v 1.142 2006/02/25 23:47:47 pkot Exp $
+  $Id: common.h,v 1.147 2006/06/11 20:41:39 deller Exp $
 
   G N O K I I
 
@@ -41,6 +41,7 @@
 /* Type of connection. Now we support serial connection with FBUS cable and
    IR (only with 61x0 models) */
 typedef enum {
+        GN_CT_NONE = -1,/* no connection type (error) */
 	GN_CT_Serial,   /* Serial connection. */
 	GN_CT_DAU9P,    /* Serial connection using DAU9P cable; use only with 6210/7110 if you want faster initialization */
 	GN_CT_DLR3P,    /* Serial connection using DLR3P cable */
@@ -50,7 +51,8 @@ typedef enum {
 	GN_CT_Tekram,   /* Tekram Ir-Dongle */
 	GN_CT_TCP,      /* TCP network connection */
 	GN_CT_M2BUS,	/* Serial connection with M2BUS protocol */
-	GN_CT_DKU2	/* DKU2 usb connection */
+	GN_CT_DKU2,	/* DKU2 usb connection using nokia_dku2 kernel driver */
+	GN_CT_DKU2LIBUSB /* DKU2 usb connection using libusb */
 } gn_connection_type;
 
 /* Maximum length of device name for serial port */
@@ -146,10 +148,10 @@ typedef struct {
 						      * - Position
 						      * - Aliasname
 						      * - DTMF
-						      * - Benutzerkennung (user id?)
+						      * - User ID 
 						      * - all postal fields:
 						      *  - PO Box
-						      *  - Zusatz (additional?)
+						      *  - Addition
 						      *  - Street
 						      *  - Zip Code
 						      *  - City
@@ -208,6 +210,15 @@ typedef enum {
 	GN_PHONEBOOK_ENTRY_RingtoneAdv= 0x37,
 } gn_phonebook_entry_type;
 
+typedef enum {
+	GN_PHONEBOOK_GROUP_Family,
+	GN_PHONEBOOK_GROUP_Vips,
+	GN_PHONEBOOK_GROUP_Friends,
+	GN_PHONEBOOK_GROUP_Work,
+	GN_PHONEBOOK_GROUP_Others, 
+	GN_PHONEBOOK_GROUP_None,
+} gn_phonebook_group_type;
+
 typedef struct {
 	gn_phonebook_entry_type entry_type;
 	gn_phonebook_number_type number_type;
@@ -226,7 +237,7 @@ typedef struct {
 							     nullterminator. */
 	char number[GN_PHONEBOOK_NUMBER_MAX_LENGTH + 1];  /* Number */
 	gn_memory_type memory_type;                       /* Type of memory */
-	int caller_group;                                 /* Caller group */
+	int caller_group;          /* Caller group - gn_phonebook_group_type */
 	int location;                                     /* Location */
 	gn_timestamp date;                                /* The record date and time
 							     of the number. */
@@ -524,10 +535,11 @@ typedef struct {
 	int automatic_answer; /* Does the phone auto-answer incoming call? */
 } gn_profile;
 
-/* Limits for IMEI, Revision and Model string storage. */
-#define GN_IMEI_MAX_LENGTH     20
-#define GN_REVISION_MAX_LENGTH 20
-#define GN_MODEL_MAX_LENGTH    20
+/* Limits for IMEI, Revision, Model and Manufacturer string storage. */
+#define GN_IMEI_MAX_LENGTH         20
+#define GN_REVISION_MAX_LENGTH     20
+#define GN_MODEL_MAX_LENGTH        32
+#define GN_MANUFACTURER_MAX_LENGTH 32
 
 #define GN_BCD_STRING_MAX_LENGTH 40
 
