@@ -1,6 +1,6 @@
 /*
 
-  $Id: smsd.c,v 1.48 2006/02/08 22:15:46 ja Exp $
+  $Id: smsd.c,v 1.51 2006/05/10 12:47:57 ja Exp $
 
   S M S D
 
@@ -36,6 +36,7 @@
 #include <time.h>
 #include <dlfcn.h>
 
+
 #ifndef WIN32
 # include <unistd.h>  /* for usleep */
 # include <signal.h>
@@ -52,10 +53,15 @@
 #include "misc.h"
 
 #include "gnokii.h"
+#include "config.h"
 #include "smsd.h"
 #include "lowlevel.h"
 #include "db.h"
 
+#ifdef ENABLE_NLS
+#  include <locale.h>
+#endif
+
 
 /* Hold main configuration data for smsd */
 SmsdConfig smsdConfig;
@@ -351,9 +357,6 @@ static void ReadConfig (gint argc, gchar *argv[])
               smsdConfig.dbMod, smsdConfig.libDir);
     exit (-2);
   }
-  
-  if (gn_cfg_read_default() < 0)
-    exit (-1);
 }
 
 
@@ -524,7 +527,8 @@ static void Run (void)
 int main (int argc, char *argv[])
 {
 #ifdef ENABLE_NLS
-  textdomain("gnokii");
+  textdomain ("gnokii");
+  setlocale (LC_ALL, "");
 #endif
 
   gn_elog_handler = NULL;
