@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii.c,v 1.82 2006/01/15 15:13:27 dforsi Exp $
+  $Id: xgnokii.c,v 1.87 2006/05/23 20:07:48 deller Exp $
   
   X G N O K I I
 
@@ -31,18 +31,18 @@
 
 */
 
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
-
 #include "config.h"
-#include "compat.h"
-#include "misc.h"
-
 #ifdef HAVE_ASPRINTF
 #  define _GNU_SOURCE
 #  include <stdio.h>
 #endif
 
+#include <gdk/gdkkeysyms.h>
+#include <gtk/gtk.h>
+
+#include "compat.h"
+#include "misc.h"
+
 #include <stdlib.h>		/* for getenv */
 #include <locale.h>
 #include <string.h>
@@ -704,7 +704,7 @@ void GUI_ShowOptions(void)
 	/* Phone */
 	gtk_entry_set_text(GTK_ENTRY(configDialogData.phone.model), phoneMonitor.phone.model);
 
-	gtk_entry_set_text(GTK_ENTRY(configDialogData.phone.version), phoneMonitor.phone.version);
+	gtk_entry_set_text(GTK_ENTRY(configDialogData.phone.version), phoneMonitor.phone.product_name);
 
 	gtk_entry_set_text(GTK_ENTRY(configDialogData.phone.revision), phoneMonitor.phone.revision);
 
@@ -2332,15 +2332,18 @@ static bool LocaleHelpExists(gchar *help_locale)
 
 static void ReadConfig(void)
 {
-	if (gn_cfg_read_default() < 0) {
+	if (GN_ERR_NONE != gn_lib_phoneprofile_load( NULL, &statemachine ))
 		exit(-1);
-	}
-	if (!gn_cfg_phone_load("", &statemachine)) exit(-1);
 
-	xgnokiiConfig.model = statemachine.config.model;
-	xgnokiiConfig.port = statemachine.config.port_device;
-	asprintf(&xgnokiiConfig.initlength, "%d", statemachine.config.init_length);
-	xgnokiiConfig.connection = statemachine.config.connection_type;
+	xgnokiiConfig.model = statemachine->config.model;
+	xgnokiiConfig.port = statemachine->config.port_device;
+	asprintf(&xgnokiiConfig.initlength, "%d", statemachine->config.init_length);
+	xgnokiiConfig.connection = statemachine->config.connection_type;
+	xgnokiiConfig.bindir = gn_lib_cfg_get("global", "bindir");
+	if (!xgnokiiConfig.bindir)
+		xgnokiiConfig.bindir = gn_lib_cfg_get("gnokiid", "bindir");
+	if (!xgnokiiConfig.bindir)
+		xgnokiiConfig.bindir = g_strdup("/usr/local/sbin");
 
 	max_phonebook_number_length = max_phonebook_sim_number_length =
 	    GN_PHONEBOOK_NUMBER_MAX_LENGTH;
