@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_xkeyb.c,v 1.16 2005/04/24 20:57:37 pkot Exp $
+  $Id: xgnokii_xkeyb.c,v 1.19 2006/02/17 18:24:43 dforsi Exp $
 
   X G N O K I I
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
-  & Jn Derfik <ja@mail.upjs.sk>.
+  & 1999-2005 Jan Derfinak.
   Copyright (C) 2002 BORBELY Zoltan
 
 */
@@ -138,20 +138,20 @@ static GtkWidget *GetPixmap(void)
 
 	if (!strcmp(phoneMonitor.phone.model, "6110") || !strcmp(phoneMonitor.phone.model, "6120")) {
 		button = button_6110;
-		file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir, "/xpm/6110.xpm");
+		file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir, "/xpm/keyb_6110.xpm");
 	} else if (!strcmp(phoneMonitor.phone.model, "6130") ||
 		   !strcmp(phoneMonitor.phone.model, "6150") ||
 		   !strcmp(phoneMonitor.phone.model, "616x") ||
 		   !strcmp(phoneMonitor.phone.model, "6185") ||
 		   !strcmp(phoneMonitor.phone.model, "6190")) {
 		button = button_6150;
-		file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir, "/xpm/6150.xpm");
+		file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir, "/xpm/keyb_6150.xpm");
 	} else if (!strcmp(phoneMonitor.phone.model, "5110") ||
 		   !strcmp(phoneMonitor.phone.model, "5130") ||
 		   !strcmp(phoneMonitor.phone.model, "5160") ||
 		   !strcmp(phoneMonitor.phone.model, "5190")) {
 		button = button_5110;
-		file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir, "/xpm/5110.xpm");
+		file = g_strdup_printf("%s%s", xgnokiiConfig.xgnokiidir, "/xpm/keyb_5110.xpm");
 	} else
 		return NULL;
 
@@ -269,8 +269,8 @@ void GUI_CreateXkeybWindow(void)
 
 	gtk_item_factory_create_items(item_factory, nmenu_items, menu_items, NULL);
 
-	gtk_accel_group_attach(accel_group, GTK_OBJECT(GUI_XkeybWindow));
-
+	gtk_window_add_accel_group(GTK_WINDOW(GUI_XkeybWindow), accel_group);
+	
 	/* Finally, return the actual menu bar created by the item factory. */
 	menubar = gtk_item_factory_get_widget(item_factory, "<main>");
 
@@ -283,6 +283,7 @@ void GUI_CreateXkeybWindow(void)
 	gtk_widget_show(menubar);
 
 	pixArea = gtk_fixed_new();
+	gtk_fixed_set_has_window(GTK_FIXED(pixArea), TRUE);
 	gtk_signal_connect(GTK_OBJECT(pixArea), "button_press_event",
 			   (GtkSignalFunc) ButtonEvent, NULL);
 	gtk_signal_connect(GTK_OBJECT(pixArea), "button_release_event",
