@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_xring.c,v 1.5 2005/04/24 20:57:37 pkot Exp $
+  $Id: xgnokii_xring.c,v 1.9 2006/02/17 18:24:43 dforsi Exp $
 
   X G N O K I I
 
@@ -25,6 +25,8 @@
   Copyright (C) 1999 Tomi Ollila
   Copyright (C) 2003 BORBELY Zoltan
   Copyright (C) 2004 Pawel Kot
+  Copyright (C) 2005 Jan Derfinak
+  
 
 */
 
@@ -426,10 +428,11 @@ static void load_ringtone_list(void)
 gn_ringtone_info *get_selected_ringtone(void)
 {
 	GtkList *list;
-	int pos;
+	int pos = -1;
 
 	list = GTK_LIST(GTK_COMBO(gi.rlist_combo)->list);
-	pos = gtk_list_child_position(list, list->selection->data);
+	if (list && list->selection)
+		pos = gtk_list_child_position(list, list->selection->data);
 
 	if (pos < 0 || pos > gi.ringtone_list.count) return NULL;
 
@@ -470,7 +473,7 @@ static void close_application(GtkWidget * widget, GdkEvent * event, gpointer dat
 	}
 	play_tone(0, 0, -1);
 
-	gdk_key_repeat_restore();
+//	gdk_key_repeat_restore();
 	gtk_widget_hide(gi.w);
 }
 
@@ -546,7 +549,7 @@ static gboolean button_release(GtkWidget * widget, GdkEvent * event, gpointer da
 static gboolean focus_in(GtkWidget * widget, GdkEvent * event, gpointer data)
 {
 	gi.focus = TRUE;
-	gdk_key_repeat_disable();
+//	gdk_key_repeat_disable();
 
 	return TRUE;
 }
@@ -556,7 +559,7 @@ static gboolean focus_out(GtkWidget * widget, GdkEvent * event, gpointer data)
 	tone_stop(&gi);
 
 	gi.focus = FALSE;
-	gdk_key_repeat_restore();
+//	gdk_key_repeat_restore();
 
 	return TRUE;
 }
@@ -598,11 +601,11 @@ static void read_ringtone(GtkWidget *w, GtkFileSelection *fs)
 		gi.file_name = NULL;
 	}
 
-	file_name = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
+	file_name = (gchar *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 	gtk_widget_hide(GTK_WIDGET(fs));
 
 	if ((err = gn_file_ringtone_read(file_name, &gi.ringtone)) != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error reading file\n(error=%s)"), gn_error_print(err));
+		gchar *buf = g_strdup_printf(_("Error reading file\n%s"), gn_error_print(err));
 		gtk_label_set_text(GTK_LABEL(gi.error_dialog.text), buf);
 		gtk_widget_show(gi.error_dialog.dialog);
 		g_free(buf);
@@ -635,11 +638,11 @@ static void write_ringtone(GtkWidget *w, GtkFileSelection *fs)
 	gchar *file_name;
 	gn_error err;
 
-	file_name = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
+	file_name = (gchar *) gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
 	gtk_widget_hide(GTK_WIDGET(fs));
 
 	if ((err = gn_file_ringtone_save(file_name, &gi.ringtone)) != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error writing file\n(error=%s)"), gn_error_print(err));
+		gchar *buf = g_strdup_printf(_("Error writing file\n%s"), gn_error_print(err));
 		gtk_label_set_text(GTK_LABEL(gi.error_dialog.text), buf);
 		gtk_widget_show(gi.error_dialog.dialog);
 		g_free(buf);
@@ -682,7 +685,7 @@ static void save_ringtone(GtkWidget *w)
 	}
 
 	if ((err = gn_file_ringtone_save(gi.file_name, &gi.ringtone)) != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error writing file\n(error=%s)"), gn_error_print(err));
+		gchar *buf = g_strdup_printf(_("Error writing file\n%s"), gn_error_print(err));
 		gtk_label_set_text(GTK_LABEL(gi.error_dialog.text), buf);
 		gtk_widget_show(gi.error_dialog.dialog);
 		g_free(buf);
@@ -724,10 +727,18 @@ static void get_ringtone(GtkWidget *w)
 	gn_ringtone_info *ri;
 
 	ri = get_selected_ringtone();
+	if (!ri) {
+		gchar *buf = g_strdup_printf(_("Empty ringtone list"));
+		gtk_label_set_text(GTK_LABEL(gi.error_dialog.text), buf);
+		gtk_widget_show(gi.error_dialog.dialog);
+		g_free(buf);
+		return;
+	}
+
 	gi.ringtone.location = ri->location;
 
 	if ((err = ringtone_event(Event_GetRingtone, &gi.ringtone)) != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error getting ringtone\n(error=%s)"), gn_error_print(err));
+		gchar *buf = g_strdup_printf(_("Error getting ringtone\n%s"), gn_error_print(err));
 		gtk_label_set_text(GTK_LABEL(gi.error_dialog.text), buf);
 		gtk_widget_show(gi.error_dialog.dialog);
 		g_free(buf);
@@ -744,7 +755,7 @@ static void set_ringtone(GtkWidget *w)
 	get_ringtone_info(&gi.ringtone);
 
 	if ((err = ringtone_event(Event_SetRingtone, &gi.ringtone)) != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error setting ringtone\n(error=%s)"), gn_error_print(err));
+		gchar *buf = g_strdup_printf(_("Error setting ringtone\n%s"), gn_error_print(err));
 		gtk_label_set_text(GTK_LABEL(gi.error_dialog.text), buf);
 		gtk_widget_show(gi.error_dialog.dialog);
 		g_free(buf);
@@ -763,7 +774,7 @@ static void delete_ringtone(GtkWidget *w)
 	get_ringtone_info(&ringtone);
 
 	if ((err = ringtone_event(Event_DeleteRingtone, &ringtone)) != GN_ERR_NONE) {
-		gchar *buf = g_strdup_printf(_("Error deleting ringtone\n(error=%s)"), gn_error_print(err));
+		gchar *buf = g_strdup_printf(_("Error deleting ringtone\n%s"), gn_error_print(err));
 		gtk_label_set_text(GTK_LABEL(gi.error_dialog.text), buf);
 		gtk_widget_show(gi.error_dialog.dialog);
 		g_free(buf);
@@ -842,7 +853,7 @@ void GUI_CreateXringWindow(void)
 	/* create menubar */
 
 	gi.accel = gtk_accel_group_new();
-	gtk_accel_group_attach(gi.accel, GTK_OBJECT(gi.w));
+	gtk_window_add_accel_group(GTK_WINDOW(gi.w), gi.accel);
 	gi.item_factory = gtk_item_factory_new(GTK_TYPE_MENU_BAR, "<main>", gi.accel);
 	gtk_item_factory_create_items(gi.item_factory, sizeof(menu_items) / sizeof(menu_items[0]), menu_items, NULL);
 	gi.menu = gtk_item_factory_get_widget(gi.item_factory, "<main>");
@@ -851,9 +862,9 @@ void GUI_CreateXringWindow(void)
 
 	/* create toolbar */
 
-	gi.toolbar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_ICONS);
-	gtk_toolbar_set_button_relief(GTK_TOOLBAR(gi.toolbar), GTK_RELIEF_NORMAL);
+	gi.toolbar = gtk_toolbar_new();
 	gtk_toolbar_set_style(GTK_TOOLBAR(gi.toolbar), GTK_TOOLBAR_ICONS);
+	gtk_toolbar_set_orientation(GTK_TOOLBAR(gi.toolbar), GTK_ORIENTATION_HORIZONTAL);
 
 	gtk_toolbar_append_item(GTK_TOOLBAR(gi.toolbar), NULL, _("Clear ringtone"), NULL,
 			NewPixmap(New_xpm, gi.w->window, &gi.w->style->bg[GTK_STATE_NORMAL]),
@@ -918,6 +929,7 @@ void GUI_CreateXringWindow(void)
 	/* create fixed */
 
 	gi.f = gtk_fixed_new();
+	gtk_fixed_set_has_window(GTK_FIXED(gi.f), TRUE); 
 	gtk_widget_set_usize(gi.f, 672, 160);
 	gtk_box_pack_start(GTK_BOX(gi.vbox), gi.f, FALSE, FALSE, 0);
 
